@@ -13,6 +13,7 @@ import sas.qtgui.path_prepare
 
 # Local
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
+from sas.qtgui.Perspectives.Fitting.Constraint import Constraint
 from sas.qtgui.Plotting.PlotterData import Data1D
 from sas.qtgui.Perspectives.Fitting.FittingPerspective import FittingWindow
 
@@ -211,8 +212,68 @@ class FittingPerspectiveTest(unittest.TestCase):
         self.assertEqual(self.widget.tabText(1), "BatchPage2")
         self.assertEqual(self.widget.tabText(2), "BatchPage3")
 
+    def testGetFitTabs(self):
+        '''test the fit tab getter method'''
+        # Add an empty tab
+        self.widget.addFit(None)
+        # Get the tabs
+        tabs = self.widget.getFitTabs()
+        self.assertTrue(isinstance(tabs, list))
+        self.assertEqual(len(tabs), 2)
+
+    def testGetActiveConstraintList(self):
+        '''test the active constraint getter'''
+        # Add an empty tab
+        self.widget.addFit(None)
+        # mock the getConstraintsForModel method of the FittingWidget tab of
+        # the first tab
+        tab = self.widget.tabs[0]
+        tab.getConstraintsForModel = MagicMock(return_value=[("scale",
+                                                               "M2.scale +2")])
+        # mock the getConstraintsForModel method of the FittingWidget tab of
+        # the second tab
+        tab = self.widget.tabs[1]
+        tab.getConstraintsForModel = MagicMock(return_value=[("scale",
+                                                               "M2.background "
+                                                               "+2")])
+        constraints = self.widget.getActiveConstraintList()
+
+        # we should have 2 constraints
+        self.assertEqual(len(constraints), 2)
+        self.assertEqual(constraints, [("M1.scale", "M2.scale +2"),
+                                       ('M2.scale', 'M2.background +2')])
+
+    def testGetSymbolDictForConstraints(self):
+        '''test the symbol dict getter'''
+        # Add an empty tab
+        self.widget.addFit(None)
+        # mock the getSymbolDict method of the first tab
+        tab = self.widget.tabs[0]
+        tab.getSymbolDict = MagicMock(return_value={"M1.scale": 1})
+        # mock the getSymbolDict method of the second tab
+        tab = self.widget.tabs[1]
+        tab.getSymbolDict = MagicMock(return_value={"M2.scale": 1})
+
+        symbols = self.widget.getSymbolDictForConstraints()
+        # we should have 2 symbols
+        self.assertEqual(len(symbols), 2)
+        self.assertEqual(list(symbols.keys()), ["M1.scale", "M2.scale"])
+
+    def testGetConstraintTab(self):
+        '''test the constraint tab getter'''
+        # no constraint tab is present, should return None
+        constraint_tab = self.widget.getConstraintTab()
+        self.assertEqual(constraint_tab, None)
+
+        # add a constraint tab
+        self.widget.addConstraintTab()
+        constraint_tab = self.widget.getConstraintTab()
+        self.assertEquals(constraint_tab, self.widget.tabs[1])
+
     def testSerialization(self):
         ''' Serialize fit pages and check data '''
+        self.assertTrue(hasattr(self.widget, 'isSerializable'))
+        self.assertTrue(self.widget.isSerializable())
         data = Data1D(x=[1,2], y=[1,2])
         GuiUtils.dataFromItem = MagicMock(return_value=data)
         item = QtGui.QStandardItem("test")
@@ -241,6 +302,54 @@ class FittingPerspectiveTest(unittest.TestCase):
         self.assertEqual(len(params), 28)
         self.assertEqual(page.get('data_id', None), None)
 
+    def testUpdateFromConstraints(self):
+        '''tests the method that parses the loaded project dict and retuens a dict with constrains across all fit pages'''
+        # create a constraint dict with one constraint for fit pages 1 and 2
+        constraint_dict = {'M1': [['scale', 'scale', 'M1.scale', True,
+                                 'M2.scale']],
+                           'M2': [['background', 'background',
+                                   'M2.background', True, 'M1.background']]}
+        # add a second tab
+        self.widget.addFit(None)
+        tab1 = self.widget.tabs[0]
+        tab2 = self.widget.tabs[1]
+        # mock the getRowFromName methods from both tabs
+        tab1.getRowFromName = MagicMock(return_value=0)
+        tab2.getRowFromName = MagicMock(return_value=1)
+        # mock the addConstraintToRow method of both tabs
+        tab1.addConstraintToRow = MagicMock()
+        tab2.addConstraintToRow = MagicMock()
+        # add the constraints
+        self.widget.updateFromConstraints(constraint_dict)
+        # check that getRowFromName was called correctly on both tabs
+        tab1.getRowFromName.assert_called_with("scale")
+        tab2.getRowFromName.assert_called_with("background")
+        # check that addConstraintToRow was called correctly
+        constraint1 = Constraint(param='scale',
+                                 value='scale',
+                                 value_ex="M1.scale",
+                                 func="M2.scale")
+        constraint2 = Constraint(param='background',
+                                 value='background',
+                                 value_ex="M2.background",
+                                 func="M1.background")
+        tab1_call_dict = tab1.addConstraintToRow.call_args[1]
+        tab2_call_dict = tab2.addConstraintToRow.call_args[1]
+        self.assertEqual(vars(tab1_call_dict['constraint']), vars(constraint1))
+        self.assertEqual(vars(tab2_call_dict['constraint']), vars(constraint2))
+        self.assertEqual(tab1_call_dict['row'], 0)
+        self.assertEqual(tab2_call_dict['row'], 1)
+
+    def testGetTabByName(self):
+        '''test getting a tab by its name'''
+        # add a second tab
+        self.widget.addFit(None)
+        # get the second tab
+        tab = self.widget.getTabByName('M2')
+        self.assertEqual(tab, self.widget.tabs[1])
+        # get some unexisting tab
+        tab = self.widget.getTabByName('foo')
+        self.assertFalse(tab)
 
 if __name__ == "__main__":
     unittest.main()
