@@ -175,7 +175,7 @@ class ColorMap(QtWidgets.QDialog, Ui_ColorMapUI):
             self.updateMap()
 
         self.slider.lowValueChanged.connect(set_vmin)
-        self.slider.highValueChanged.connect(set_vmin)
+        self.slider.highValueChanged.connect(set_vmax)
 
     def updateMap(self):
         self._norm = mpl.colors.Normalize(vmin=self.vmin, vmax=self.vmax)
